//////////////////////////////////////////////////////////////////////////////////
// Vector2d V1.0.0
// (c) 2010 by R Cecco. <http://www.professorcloud.com>
// MIT License
//
// Please retain this copyright header in all versions of the software
//////////////////////////////////////////////////////////////////////////////////

// A handy 2d vector class.
function Vector2d()
{
	if (arguments.length == 1)
	{
		this.vx = arguments[0].vx;
		this.vy = arguments[0].vy;
	}
	else
	{
		this.vx = arguments[0];
		this.vy = arguments[1];
	}
	
	// Multiply vector.
	Vector2d.prototype.mul = function(mul)
	{
		this.vx *= mul;
		this.vy *= mul;
	};
	
	// Add a vector.
	Vector2d.prototype.add = function(v2)
	{
		this.vx += v2.vx;
		this.vy += v2.vy;
	};
	
	// Subtract a vector.
	Vector2d.prototype.sub = function(v2)
	{
		this.vx -= v2.vx;
		this.vy -= v2.vy;
	};
	
	// Length of vector.
	Vector2d.prototype.len = function()
	{
		return Math.sqrt(this.vx*this.vx + this.vy*this.vy);
	};
	
	// Normalise (unit length). Also returns length before normalisation.
	Vector2d.prototype.normalise = function()
	{
		var len = Math.sqrt(this.vx*this.vx + this.vy*this.vy);
		this.vx /= len;
		this.vy /= len;
		return len;
	};
		
	// Dot product.	
	Vector2d.prototype.dotProd = function(v2)
	{
		return (this.vx * v2.vx) + (this.vy * v2.vy);
	};
	
	// Rotate vector by an angle in radians.
	Vector2d.prototype.rotate = function(ang)
	{
		this.vx = (this.vx * Math.cos(ang)) - (this.vy * Math.sin(ang));
		this.vy = (this.vy * Math.cos(ang)) + (this.vx * Math.sin(ang));
	};
	
	// Negate vector (point in opposite direction).
	Vector2d.prototype.negate = function()
	{
		this.vx = -this.vx;
		this.vy = -this.vy;
	};
	
	//toString function.
	Vector2d.prototype.toString = function()
	{
		return 'vx = ' + this.vx + ', vy = ' + this.vy;
	};
}
